# THIS FILE IS GENERATED DURING PROJECT BUILD
# See poetry poetry-versions-plugin for details

branch = 'release/0.4.0'
commit = '3cf82c0'
commit_count = 54
is_dirty = False
datetime = '2024-12-02 20:43:54'
version = '0.4.0'

full_version = f'{version}.{branch}+{commit_count}.{commit}'
# END OF GENERATED CODE
